@@ -21,7 +21,7 @@ Settings = NestedDict({
     'out_dir': None,
     'content_dir': None,
     'url_prefix': None,
-    'default-toc': True,
+    'default_toc': True,
     'base_url': '',
     'cache_enabled': True,
     'log_level': "Info",
@@ -46,6 +46,7 @@ Settings = NestedDict({
             'links': []
         },
         'meta': {
+            'search_console_code': None,
             'description': "",
             'keywords': [],
             'categories': [],
@@ -73,7 +74,8 @@ Settings = NestedDict({
             'js': True,
             'xml': True,
             'json': True
-        }
+        },
+    'extras': {}
 })
 
 
